@@ -11,10 +11,11 @@ from fast_boot.security.access.permission_evaluator import (
 )
 from fast_boot.security.authentication import AuthenticationTrustResolver
 from fast_boot.security.core import GrantedAuthorityDefaults
+from fast_boot.security_lite.access_decision_manager import AccessDecisionManager
 
 
 class FastApplication(FastAPI, ApplicationContext):
-    bean_factory: Dict[Type, Any]
+    bean_factory: Dict[Type, Any] = {}
     INSTANCE: ApplicationContext
 
     def setup(self) -> None:
@@ -23,7 +24,8 @@ class FastApplication(FastAPI, ApplicationContext):
             RoleHierarchy,
             GrantedAuthorityDefaults,
             PermissionEvaluator,
-            AuthenticationTrustResolver
+            AuthenticationTrustResolver,
+            AccessDecisionManager
         }
         self.bean_factory = {bean: bean() for bean in beans}
         self.INSTANCE = self
@@ -40,5 +42,14 @@ class FastApplication(FastAPI, ApplicationContext):
     def set_bean(self, bean: Any) -> None:
         self.bean_factory.update({type(bean): bean})
 
+    def put_bean(self, bean_name: Type, bean: Any) -> None:
+        assert isinstance(bean, bean_name), TypeError("Bean must be an instance of bean_name")
+        self.bean_factory.update({bean_name: bean})
+
+    def update_bean(self, bean_dict: Dict) -> None:
+        for bean_name, bean in bean_dict.items():
+            assert isinstance(bean, bean_name), TypeError("Bean must be an instance of bean_name")
+        self.bean_factory.update(bean_dict)
+
     def get_bean(self, type: Type[T]) -> T:
         return self.bean_factory.get(type)
